import { 
  select, 
  csv, 
  scaleLinear, 
  max, 
  scaleBand, 
  axisLeft,
  axisBottom 
} from 'd3'

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');
const margin = {top: 20, bottom: 30, left: 100, right: 50};
const innerHeight = height - margin.top - margin.bottom;
const innerWidth = width - margin.left - margin.right;
const g = svg.append('g').attr('transform', `translate(${margin.left},${margin.top})`);


const render = data => {
	
  
  const xScale = scaleLinear()
  							 .domain([0, max(data, data => data.population)])
  							 .range([0, innerWidth]);
  
  const yScale = scaleBand()
  							 .domain(data.map(d => d.country))
  					     .range([0, innerHeight])
  	             .padding(.1);
  
  const yAxis = axisLeft(yScale);
  const xAxis = axisBottom(xScale);

   g.append('g').call(yAxis);
  
  
   g.append('g')
  .attr('transform', `translate(0, ${innerHeight})`)
  .call(xAxis);
  
  
  g.selectAll('rect')
   .data(data)
   .enter()
   .append('rect')
   .attr('y', d => yScale(d.country))
   .attr('height', yScale.bandwidth())
   .attr('width', d => xScale(d.population))
  
};






csv('data.csv').then(data => {
  
  data.forEach(d => {
    d.population = +d.population * 1000
  });
  
	render(data);
});